Installation
============

Installing/upgrading from the PyPI
----------------------------------

To install the latest stable version from the PyPI:

.. code-block:: shell-session

    $ pip install -U marshmallow

To install the latest pre-release version from the PyPI:

.. code-block:: shell-session

    $ pip install -U marshmallow --pre

Get the bleeding edge version
-----------------------------

To get the latest development version of marshmallow, run

.. code-block:: shell-session

    $ pip install -U git+https://github.com/marshmallow-code/marshmallow.git@dev


.. seealso::

    Need help upgrading to newer releases? See the :doc:`upgrading` page.
